@@ -130,8 +130,8 @@ static PyMethodDef t_replaceable_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(Replaceable, t_replaceable, UObject, Replaceable,
-             abstract_init, NULL)
+DECLARE_DEALLOC_TYPE(Replaceable, t_replaceable, UObject,
+                     Replaceable, abstract_init)
 
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(55, 0, 0)
@@ -157,8 +157,8 @@ static PyMethodDef t_python_replaceable_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(PythonReplaceable, t_python_replaceable, Replaceable,
-             PythonReplaceable, t_python_replaceable_init, NULL)
+DECLARE_DEALLOC_TYPE(PythonReplaceable, t_python_replaceable, Replaceable,
+                     PythonReplaceable, t_python_replaceable_init)
 
 
 PythonReplaceable::PythonReplaceable(PyObject *self) : self_(self)
@@ -391,7 +391,11 @@ static PyObject *t_unicodestring_indexOf(t_unicodestring *self, PyObject *args);
 static PyObject *t_unicodestring_lastIndexOf(t_unicodestring *self,
                                              PyObject *args);
 static PyObject *t_unicodestring_trim(t_unicodestring *self);
-static PyObject *t_unicodestring_reverse(t_unicodestring *self);
+static PyObject *t_unicodestring_truncate(t_unicodestring *self, PyObject *arg);
+static PyObject *t_unicodestring_reverse(t_unicodestring *self, PyObject *args);
+static PyObject *t_unicodestring_remove(t_unicodestring *self, PyObject *args);
+static PyObject *t_unicodestring_removeBetween(t_unicodestring *self, PyObject *args);
+static PyObject *t_unicodestring_retainBetween(t_unicodestring *self, PyObject *args);
 static PyObject *t_unicodestring_toUpper(t_unicodestring *self, PyObject *args);
 static PyObject *t_unicodestring_toLower(t_unicodestring *self, PyObject *args);
 static PyObject *t_unicodestring_toTitle(t_unicodestring *self, PyObject *args);
@@ -434,7 +438,11 @@ static PyMethodDef t_unicodestring_methods[] = {
     DECLARE_METHOD(t_unicodestring, indexOf, METH_VARARGS),
     DECLARE_METHOD(t_unicodestring, lastIndexOf, METH_VARARGS),
     DECLARE_METHOD(t_unicodestring, trim, METH_NOARGS),
-    DECLARE_METHOD(t_unicodestring, reverse, METH_NOARGS),
+    DECLARE_METHOD(t_unicodestring, truncate, METH_O),
+    DECLARE_METHOD(t_unicodestring, reverse, METH_VARARGS),
+    DECLARE_METHOD(t_unicodestring, remove, METH_VARARGS),
+    DECLARE_METHOD(t_unicodestring, removeBetween, METH_VARARGS),
+    DECLARE_METHOD(t_unicodestring, retainBetween, METH_VARARGS),
     DECLARE_METHOD(t_unicodestring, toUpper, METH_VARARGS),
     DECLARE_METHOD(t_unicodestring, toLower, METH_VARARGS),
     DECLARE_METHOD(t_unicodestring, toTitle, METH_VARARGS),
@@ -453,8 +461,8 @@ static PyMethodDef t_unicodestring_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(UnicodeString, t_unicodestring, Replaceable, UnicodeString,
-             t_unicodestring_init, NULL)
+DECLARE_DEALLOC_TYPE(UnicodeString, t_unicodestring, Replaceable,
+                     UnicodeString, t_unicodestring_init)
 
 /* Formattable */
 
@@ -494,8 +502,8 @@ static PyMethodDef t_formattable_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(Formattable, t_formattable, UObject, Formattable,
-             t_formattable_init, NULL)
+DECLARE_DEALLOC_TYPE(Formattable, t_formattable, UObject,
+                     Formattable, t_formattable_init)
 
 PyObject *wrap_Formattable(Formattable &formattable)
 {
@@ -525,8 +533,8 @@ static PyMethodDef t_stringenumeration_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(StringEnumeration, t_stringenumeration, UObject,
-             StringEnumeration, abstract_init, NULL)
+DECLARE_DEALLOC_TYPE(StringEnumeration, t_stringenumeration, UObject,
+                     StringEnumeration, abstract_init)
 
 
 /* UMemory */
@@ -1042,7 +1050,11 @@ static PyObject *t_unicodestring_append(t_unicodestring *self, PyObject *args)
         }
         if (!parseArgs(args, "i", &i))
         {
+#if PY_VERSION_HEX < 0x030d0000
             if (sizeof(Py_UNICODE) == sizeof(UChar))
+#else
+            if (sizeof(wchar_t) == sizeof(UChar))
+#endif
                 self->object->append((UChar) i);
             else
                 self->object->append((UChar32) i);
@@ -1314,7 +1326,11 @@ static PyObject *t_unicodestring_indexOf(t_unicodestring *self, PyObject *args)
         {
             int i;
 
+#if PY_VERSION_HEX < 0x030d0000
             if (sizeof(Py_UNICODE) == sizeof(UChar))
+#else
+            if (sizeof(wchar_t) == sizeof(UChar))
+#endif
                 i = self->object->indexOf((UChar) c);
             else
                 i = self->object->indexOf((UChar32) c);
@@ -1339,7 +1355,11 @@ static PyObject *t_unicodestring_indexOf(t_unicodestring *self, PyObject *args)
             {
                 int i;
 
+#if PY_VERSION_HEX < 0x030d0000
                 if (sizeof(Py_UNICODE) == sizeof(UChar))
+#else
+                if (sizeof(wchar_t) == sizeof(UChar))
+#endif
                     i = self->object->indexOf((UChar) c, start);
                 else
                     i = self->object->indexOf((UChar32) c, start);
@@ -1367,7 +1387,11 @@ static PyObject *t_unicodestring_indexOf(t_unicodestring *self, PyObject *args)
             {
                 int i;
 
+#if PY_VERSION_HEX < 0x030d0000
                 if (sizeof(Py_UNICODE) == sizeof(UChar))
+#else
+                if (sizeof(wchar_t) == sizeof(UChar))
+#endif
                     i = self->object->indexOf((UChar) c, start, len);
                 else
                     i = self->object->indexOf((UChar32) c, start, len);
@@ -1413,7 +1437,11 @@ static PyObject *t_unicodestring_lastIndexOf(t_unicodestring *self,
         {
             int i;
 
+#if PY_VERSION_HEX < 0x030d0000
             if (sizeof(Py_UNICODE) == sizeof(UChar))
+#else
+            if (sizeof(wchar_t) == sizeof(UChar))
+#endif
                 i = self->object->lastIndexOf((UChar) c);
             else
                 i = self->object->lastIndexOf((UChar32) c);
@@ -1438,7 +1466,11 @@ static PyObject *t_unicodestring_lastIndexOf(t_unicodestring *self,
             {
                 int i;
 
+#if PY_VERSION_HEX < 0x030d0000
                 if (sizeof(Py_UNICODE) == sizeof(UChar))
+#else
+                if (sizeof(wchar_t) == sizeof(UChar))
+#endif
                     i = self->object->lastIndexOf((UChar) c, start);
                 else
                     i = self->object->lastIndexOf((UChar32) c, start);
@@ -1466,7 +1498,11 @@ static PyObject *t_unicodestring_lastIndexOf(t_unicodestring *self,
             {
                 int i;
 
+#if PY_VERSION_HEX < 0x030d0000
                 if (sizeof(Py_UNICODE) == sizeof(UChar))
+#else
+                if (sizeof(wchar_t) == sizeof(UChar))
+#endif
                     i = self->object->lastIndexOf((UChar) c, start, len);
                 else
                     i = self->object->lastIndexOf((UChar32) c, start, len);
@@ -1502,10 +1538,117 @@ static PyObject *t_unicodestring_trim(t_unicodestring *self)
     Py_RETURN_SELF();
 }
 
-static PyObject *t_unicodestring_reverse(t_unicodestring *self)
+static PyObject *t_unicodestring_truncate(t_unicodestring *self, PyObject *arg)
 {
-    self->object->reverse();
-    Py_RETURN_SELF();
+    int length;
+
+    if (!parseArg(arg, "i", &length))
+    {
+        self->object->truncate(length);
+        Py_RETURN_SELF();
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "truncate", arg);
+}
+
+static PyObject *t_unicodestring_reverse(t_unicodestring *self, PyObject *args)
+{
+    int start, length;
+
+    switch (PyTuple_Size(args)) {
+      case 0:
+        self->object->reverse();
+        Py_RETURN_SELF();
+      case 2:
+        if (!parseArgs(args, "ii", &start, &length))
+        {
+            self->object->reverse(start, length);
+            Py_RETURN_SELF();
+        }
+        break;
+    }
+        
+    return PyErr_SetArgsError((PyObject *) self, "reverse", args);
+}
+
+static PyObject *t_unicodestring_remove(t_unicodestring *self, PyObject *args)
+{
+    int start, length;
+
+    switch (PyTuple_Size(args)) {
+      case 0:
+        self->object->remove();
+        Py_RETURN_SELF();
+      case 1:
+        if (!parseArgs(args, "i", &start))
+        {
+            self->object->remove(start);
+            Py_RETURN_SELF();
+        }
+        break;
+      case 2:
+        if (!parseArgs(args, "ii", &start, &length))
+        {
+            self->object->remove(start, length);
+            Py_RETURN_SELF();
+        }
+        break;
+    }
+        
+    return PyErr_SetArgsError((PyObject *) self, "remove", args);
+}
+
+static PyObject *t_unicodestring_removeBetween(t_unicodestring *self, PyObject *args)
+{
+    int start, limit;
+
+    switch (PyTuple_Size(args)) {
+      case 0:
+        self->object->remove();
+        Py_RETURN_SELF();
+      case 1:
+        if (!parseArgs(args, "i", &start))
+        {
+            self->object->removeBetween(start);
+            Py_RETURN_SELF();
+        }
+        break;
+      case 2:
+        if (!parseArgs(args, "ii", &start, &limit))
+        {
+            self->object->removeBetween(start, limit);
+            Py_RETURN_SELF();
+        }
+        break;
+    }
+        
+    return PyErr_SetArgsError((PyObject *) self, "removeBetween", args);
+}
+
+static PyObject *t_unicodestring_retainBetween(t_unicodestring *self, PyObject *args)
+{
+    int start, limit;
+
+    switch (PyTuple_Size(args)) {
+      case 0:
+        Py_RETURN_SELF();
+      case 1:
+        if (!parseArgs(args, "i", &start))
+        {
+            self->object->retainBetween(start);
+            Py_RETURN_SELF();
+        }
+        break;
+      case 2:
+        if (!parseArgs(args, "ii", &start, &limit))
+        {
+            self->object->retainBetween(start, limit);
+            Py_RETURN_SELF();
+        }
+        break;
+    }
+        
+    return PyErr_SetArgsError((PyObject *) self, "retainBetween", args);
 }
 
 static PyObject *t_unicodestring_toUpper(t_unicodestring *self, PyObject *args)
@@ -1706,8 +1849,8 @@ static PyObject *t_unicodestring_encode(t_unicodestring *self, PyObject *arg)
 static PyObject *t_unicodestring_countChar32(t_unicodestring *self,
                                              PyObject *args)
 {
-    int32_t start = 0, length = INT32_MAX;
-    int32_t len;
+    int start = 0, length = INT32_MAX;
+    int len;
 
     switch (PyTuple_Size(args)) {
       case 0:
@@ -2068,7 +2211,7 @@ static int t_unicodestring_ass_item(t_unicodestring *self,
 
     if (n >= 0 && n < len)
     {
-        int32_t i;
+        int i;
 
         if (!parseArg(arg, "i", &i))
         {
