@@ -50,6 +50,7 @@ DECLARE_CONSTANTS_TYPE(UBidiPairedBracketType)
 DECLARE_CONSTANTS_TYPE(UIndicPositionalCategory)
 DECLARE_CONSTANTS_TYPE(UIndicSyllabicCategory)
 DECLARE_CONSTANTS_TYPE(UVerticalOrientation)
+DECLARE_CONSTANTS_TYPE(UCPMapRangeOption)
 #endif
 #if U_ICU_VERSION_HEX >= VERSION_HEX(75, 0, 0)
 DECLARE_CONSTANTS_TYPE(UIdentifierType)
@@ -70,6 +71,7 @@ static int t_char_init(t_char *self, PyObject *args, PyObject *kwds);
 static PyObject *t_char_hasBinaryProperty(PyTypeObject *type, PyObject *args);
 #if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
 static PyObject *t_char_getBinaryPropertySet(PyTypeObject *type, PyObject *arg);
+static PyObject *t_char_getIntPropertyMap(PyTypeObject *type, PyObject *arg);
 #endif
 static PyObject *t_char_getIntPropertyValue(PyTypeObject *type, PyObject *args);
 static PyObject *t_char_getIntPropertyMinValue(PyTypeObject *type,
@@ -142,6 +144,7 @@ static PyMethodDef t_char_methods[] = {
     DECLARE_METHOD(t_char, hasBinaryProperty, METH_VARARGS | METH_CLASS),
 #if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
     DECLARE_METHOD(t_char, getBinaryPropertySet, METH_O | METH_CLASS),
+    DECLARE_METHOD(t_char, getIntPropertyMap, METH_O | METH_CLASS),
 #endif
     DECLARE_METHOD(t_char, getIntPropertyValue, METH_VARARGS | METH_CLASS),
     DECLARE_METHOD(t_char, getIntPropertyMinValue, METH_O | METH_CLASS),
@@ -215,6 +218,33 @@ static void t_char_dealloc(t_char *self)
 
 DECLARE_STRUCT(Char, t_char, UNone, t_char_init, t_char_dealloc)
 
+/* UCPMap */
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
+
+class t_ucpmap : public _wrapper {
+public:
+    UCPMap *object;
+};
+
+static PyObject *t_ucpmap_get(t_ucpmap *self, PyObject *arg);
+static PyObject *t_ucpmap_getRange(t_ucpmap *self, PyObject *args);
+
+static PyMethodDef t_ucpmap_methods[] = {
+    DECLARE_METHOD(t_ucpmap, get, METH_O),
+    DECLARE_METHOD(t_ucpmap, getRange, METH_VARARGS),
+    { NULL, NULL, 0, NULL }
+};
+
+static void t_ucpmap_dealloc(t_char *self)
+{
+    Py_TYPE(self)->tp_free((PyObject *) self);
+}
+
+DECLARE_STRUCT(UCPMap, t_ucpmap, UCPMap, abstract_init, t_ucpmap_dealloc)
+
+#endif  // ICU >= 63
+
 /* Char */
 
 static int t_char_init(t_char *self, PyObject *args, PyObject *kwds)
@@ -249,6 +279,7 @@ static PyObject *t_char_hasBinaryProperty(PyTypeObject *type, PyObject *args)
 }
 
 #if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
+
 static PyObject *t_char_getBinaryPropertySet(PyTypeObject *type, PyObject *arg)
 {
     UProperty prop;
@@ -264,7 +295,23 @@ static PyObject *t_char_getBinaryPropertySet(PyTypeObject *type, PyObject *arg)
 
     return PyErr_SetArgsError((PyObject *) type, "getBinaryPropertySet", arg);
 }
-#endif
+
+static PyObject *t_char_getIntPropertyMap(PyTypeObject *type, PyObject *arg)
+{
+    UProperty prop;
+
+    if (!parseArg(arg, "i", &prop))
+    {
+        const UCPMap *map;
+        STATUS_CALL(map = u_getIntPropertyMap(prop, &status));
+
+        return wrap_UCPMap(const_cast<UCPMap *>(map), 0);
+    }
+
+    return PyErr_SetArgsError((PyObject *) type, "getIntPropertyMap", arg);
+}
+
+#endif  // ICU >= 63
 
 static PyObject *t_char_getIntPropertyValue(PyTypeObject *type, PyObject *args)
 {
@@ -988,6 +1035,53 @@ static PyObject *t_char_getIDTypes(PyTypeObject *type, PyObject *arg)
 }
 #endif  // ICU >= 75
 
+/* UCPMap */
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
+
+static PyObject *t_ucpmap_get(t_ucpmap *self, PyObject *arg)
+{
+    UChar32 c;
+
+    if (!parseArg(arg, "i", &c))
+    {
+        return PyInt_FromLong(ucpmap_get(self->object, c));
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "get", arg);
+}
+
+static PyObject *t_ucpmap_getRange(t_ucpmap *self, PyObject *args)
+{
+    UChar32 start;
+    int option, surrogateValue = 0;
+
+    switch (PyTuple_Size(args)) {
+      case 1:
+        if (!parseArgs(args, "i", &start))
+        {
+            return PyInt_FromLong(ucpmap_getRange(self->object, start, UCPMAP_RANGE_NORMAL, 0, NULL, NULL, NULL));
+        }
+        break;
+      case 2:
+        if (!parseArgs(args, "ii", &start, &option))
+        {
+            return PyInt_FromLong(ucpmap_getRange(self->object, start, (UCPMapRangeOption) option, (uint32_t) surrogateValue, NULL, NULL, NULL));
+        }
+        break;
+      case 3:
+        if (!parseArgs(args, "iii", &start, &option, &surrogateValue))
+        {
+            return PyInt_FromLong(ucpmap_getRange(self->object, start, (UCPMapRangeOption) option, (uint32_t) surrogateValue, NULL, NULL, NULL));
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "getRange", args);
+}
+
+#endif  // ICU >= 63
+
 
 void _init_char(PyObject *m)
 {
@@ -1009,12 +1103,17 @@ void _init_char(PyObject *m)
     INSTALL_CONSTANTS_TYPE(UIndicPositionalCategory, m);
     INSTALL_CONSTANTS_TYPE(UIndicSyllabicCategory, m);
     INSTALL_CONSTANTS_TYPE(UVerticalOrientation, m);
+    INSTALL_CONSTANTS_TYPE(UCPMapRangeOption, m);
 #endif
 #if U_ICU_VERSION_HEX >= VERSION_HEX(75, 0, 0)
     INSTALL_CONSTANTS_TYPE(UIdentifierType, m);
     INSTALL_CONSTANTS_TYPE(UIdentifierStatus, m);
 #endif
+
     INSTALL_STRUCT(Char, m);
+#if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
+    INSTALL_STRUCT(UCPMap, m);
+#endif
 
     INSTALL_ENUM(Char, "FOLD_CASE_DEFAULT", U_FOLD_CASE_DEFAULT);
     INSTALL_ENUM(Char, "FOLD_CASE_EXCLUDE_SPECIAL_I", U_FOLD_CASE_EXCLUDE_SPECIAL_I);
@@ -1079,6 +1178,7 @@ void _init_char(PyObject *m)
 #endif
     INSTALL_ENUM(UProperty, "BIDI_CLASS", UCHAR_BIDI_CLASS);
     INSTALL_ENUM(UProperty, "INT_START", UCHAR_INT_START);
+    INSTALL_ENUM(UProperty, "INT_LIMIT", UCHAR_INT_LIMIT);
     INSTALL_ENUM(UProperty, "BLOCK", UCHAR_BLOCK);
     INSTALL_ENUM(UProperty, "CANONICAL_COMBINING_CLASS", UCHAR_CANONICAL_COMBINING_CLASS);
     INSTALL_ENUM(UProperty, "DECOMPOSITION_TYPE", UCHAR_DECOMPOSITION_TYPE);
@@ -1154,6 +1254,11 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UProperty, "RGI_EMOJI_ZWJ_SEQUENCE", UCHAR_RGI_EMOJI_ZWJ_SEQUENCE);
     INSTALL_ENUM(UProperty, "RGI_EMOJI", UCHAR_RGI_EMOJI);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(74, 0, 0)
+    INSTALL_ENUM(UProperty, "IDS_UNARY_OPERATOR", UCHAR_IDS_UNARY_OPERATOR);
+    INSTALL_ENUM(UProperty, "ID_COMPAT_MATH_START", UCHAR_ID_COMPAT_MATH_START);
+    INSTALL_ENUM(UProperty, "ID_COMPAT_MATH_CONTINUE", UCHAR_ID_COMPAT_MATH_CONTINUE);
+#endif
 #if U_ICU_VERSION_HEX >= VERSION_HEX(75, 0, 0)
     INSTALL_ENUM(UProperty, "IDENTIFIER_STATUS", UCHAR_IDENTIFIER_STATUS);
     INSTALL_ENUM(UProperty, "IDENTIFIER_TYPE", UCHAR_IDENTIFIER_TYPE);
@@ -1576,6 +1681,17 @@ void _init_char(PyObject *m)
 #endif
 #if U_ICU_VERSION_HEX >= VERSION_HEX(74, 0, 0)
     INSTALL_ENUM(UBlockCode, "CJK_UNIFIED_IDEOGRAPHS_EXTENSION_I", UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_I);
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(76, 0, 0)
+    INSTALL_ENUM(UBlockCode, "EGYPTIAN_HIEROGLYPHS_EXTENDED_A", UBLOCK_EGYPTIAN_HIEROGLYPHS_EXTENDED_A);
+    INSTALL_ENUM(UBlockCode, "GARAY", UBLOCK_GARAY);
+    INSTALL_ENUM(UBlockCode, "GURUNG_KHEMA", UBLOCK_GURUNG_KHEMA);
+    INSTALL_ENUM(UBlockCode, "MYANMAR_EXTENDED_C", UBLOCK_MYANMAR_EXTENDED_C);
+    INSTALL_ENUM(UBlockCode, "OL_ONAL", UBLOCK_OL_ONAL);
+    INSTALL_ENUM(UBlockCode, "SUNUWAR", UBLOCK_SUNUWAR);
+    INSTALL_ENUM(UBlockCode, "SYMBOLS_FOR_LEGACY_COMPUTING_SUPPLEMENT", UBLOCK_SYMBOLS_FOR_LEGACY_COMPUTING_SUPPLEMENT);
+    INSTALL_ENUM(UBlockCode, "TODHRI", UBLOCK_TODHRI);
+    INSTALL_ENUM(UBlockCode, "TULU_TIGALARI", UBLOCK_TULU_TIGALARI);
 #endif
     INSTALL_ENUM(UBlockCode, "INVALID_CODE", UBLOCK_INVALID_CODE);
 
@@ -1650,11 +1766,18 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UIndicSyllabicCategory, "VOWEL", U_INSC_VOWEL);
     INSTALL_ENUM(UIndicSyllabicCategory, "VOWEL_DEPENDENT", U_INSC_VOWEL_DEPENDENT);
     INSTALL_ENUM(UIndicSyllabicCategory, "VOWEL_INDEPENDENT", U_INSC_VOWEL_INDEPENDENT);
-
+#if U_ICU_VERSION_HEX >= VERSION_HEX(76, 0, 0)
+    INSTALL_ENUM(UIndicSyllabicCategory, "REORDERING_KILLER", U_INSC_REORDERING_KILLER);
+#endif
+    
     INSTALL_ENUM(UVerticalOrientation, "ROTATED", U_VO_ROTATED);
     INSTALL_ENUM(UVerticalOrientation, "TRANSFORMED_ROTATED", U_VO_TRANSFORMED_ROTATED);
     INSTALL_ENUM(UVerticalOrientation, "TRANSFORMED_UPRIGHT", U_VO_TRANSFORMED_UPRIGHT);
     INSTALL_ENUM(UVerticalOrientation, "UPRIGHT", U_VO_UPRIGHT);
+
+    INSTALL_ENUM(UCPMapRangeOption, "NORMAL", UCPMAP_RANGE_NORMAL);
+    INSTALL_ENUM(UCPMapRangeOption, "FIXED_LEAD_SURROGATES", UCPMAP_RANGE_FIXED_LEAD_SURROGATES);
+    INSTALL_ENUM(UCPMapRangeOption, "FIXED_ALL_SURROGATES", UCPMAP_RANGE_FIXED_ALL_SURROGATES);
 #endif  // ICU >= 63
 
 #if U_ICU_VERSION_HEX >= 0x04000000
@@ -1754,6 +1877,9 @@ void _init_char(PyObject *m)
     INSTALL_ENUM(UJoiningGroup, "THIN_YEH", U_JG_THIN_YEH);
     INSTALL_ENUM(UJoiningGroup, "VERTICAL_TAIL", U_JG_VERTICAL_TAIL);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(76, 0, 0)
+    INSTALL_ENUM(UJoiningGroup, "KASHMIRI_YEH", U_JG_KASHMIRI_YEH);
+#endif
 
     INSTALL_ENUM(ULineBreak, "INSEPARABLE", U_LB_INSEPARABLE);
     INSTALL_ENUM(ULineBreak, "NEXT_LINE", U_LB_NEXT_LINE);
