@@ -100,6 +100,11 @@ static PyObject *t_dateformatsymbols_getLocalPatternChars(t_dateformatsymbols *s
 static PyObject *t_dateformatsymbols_setLocalPatternChars(t_dateformatsymbols *self, PyObject *arg);
 static PyObject *t_dateformatsymbols_getLocale(t_dateformatsymbols *self,
                                                PyObject *args);
+static PyObject *t_dateformatsymbols_getEraNames(t_dateformatsymbols *self);
+static PyObject *t_dateformatsymbols_getZoneStrings(t_dateformatsymbols *self);
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
+static PyObject *t_dateformatsymbols_getZodiacNames(t_dateformatsymbols *self, PyObject *args);
+#endif
 
 static PyMethodDef t_dateformatsymbols_methods[] = {
     DECLARE_METHOD(t_dateformatsymbols, getEras, METH_NOARGS),
@@ -117,11 +122,16 @@ static PyMethodDef t_dateformatsymbols_methods[] = {
     DECLARE_METHOD(t_dateformatsymbols, getLocalPatternChars, METH_VARARGS),
     DECLARE_METHOD(t_dateformatsymbols, setLocalPatternChars, METH_O),
     DECLARE_METHOD(t_dateformatsymbols, getLocale, METH_VARARGS),
+    DECLARE_METHOD(t_dateformatsymbols, getEraNames, METH_NOARGS),
+    DECLARE_METHOD(t_dateformatsymbols, getZoneStrings, METH_NOARGS),
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
+    DECLARE_METHOD(t_dateformatsymbols, getZodiacNames, METH_VARARGS),
+#endif
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(DateFormatSymbols, t_dateformatsymbols, UObject,
-             DateFormatSymbols, t_dateformatsymbols_init, NULL)
+DECLARE_DEALLOC_TYPE(DateFormatSymbols, t_dateformatsymbols, UObject,
+                     DateFormatSymbols, t_dateformatsymbols_init)
 
 /* DateFormat */
 
@@ -182,7 +192,8 @@ static PyMethodDef t_dateformat_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(DateFormat, t_dateformat, Format, DateFormat, abstract_init, NULL)
+DECLARE_DEALLOC_TYPE(DateFormat, t_dateformat, Format,
+                     DateFormat, abstract_init)
 
 /* SimpleDateFormat */
 
@@ -219,8 +230,8 @@ static PyMethodDef t_simpledateformat_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(SimpleDateFormat, t_simpledateformat, DateFormat,
-             SimpleDateFormat, t_simpledateformat_init, NULL)
+DECLARE_DEALLOC_TYPE(SimpleDateFormat, t_simpledateformat, DateFormat,
+                     SimpleDateFormat, t_simpledateformat_init)
 
 PyObject *wrap_DateFormat(DateFormat *format)
 {
@@ -311,8 +322,9 @@ static PyMethodDef t_datetimepatterngenerator_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(DateTimePatternGenerator, t_datetimepatterngenerator,
-             UObject, DateTimePatternGenerator, abstract_init, NULL)
+DECLARE_DEALLOC_TYPE(
+    DateTimePatternGenerator, t_datetimepatterngenerator, UObject,
+    DateTimePatternGenerator, abstract_init)
 
 #if U_ICU_VERSION_HEX >= 0x04000000
 
@@ -334,8 +346,8 @@ static PyMethodDef t_dateinterval_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(DateInterval, t_dateinterval, UObject, DateInterval,
-             t_dateinterval_init, NULL)
+DECLARE_DEALLOC_TYPE(DateInterval, t_dateinterval, UObject,
+                     DateInterval, t_dateinterval_init)
 
 /* DateIntervalInfo */
 
@@ -363,8 +375,8 @@ static PyMethodDef t_dateintervalinfo_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(DateIntervalInfo, t_dateintervalinfo, UObject, DateIntervalInfo,
-             t_dateintervalinfo_init, NULL)
+DECLARE_DEALLOC_TYPE(DateIntervalInfo, t_dateintervalinfo, UObject,
+                     DateIntervalInfo, t_dateintervalinfo_init)
 
 /* DateIntervalFormat */
 
@@ -412,8 +424,8 @@ static PyMethodDef t_dateintervalformat_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(DateIntervalFormat, t_dateintervalformat, Format,
-             DateIntervalFormat, abstract_init, NULL)
+DECLARE_DEALLOC_TYPE(DateIntervalFormat, t_dateintervalformat, Format,
+                     DateIntervalFormat, abstract_init)
 
 #endif
 
@@ -469,8 +481,9 @@ static PyMethodDef t_relativedatetimeformatter_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(RelativeDateTimeFormatter, t_relativedatetimeformatter, UObject,
-             RelativeDateTimeFormatter, t_relativedatetimeformatter_init, NULL)
+DECLARE_DEALLOC_TYPE(
+    RelativeDateTimeFormatter, t_relativedatetimeformatter, UObject,
+    RelativeDateTimeFormatter, t_relativedatetimeformatter_init)
 
 #endif
 
@@ -571,6 +584,9 @@ static PyObject *fromUnicodeStringArray(const UnicodeString *strings,
 {
     PyObject *list = PyList_New(len);
 
+    if (list == NULL)
+        return NULL;
+
     for (int i = 0; i < len; i++) {
         UnicodeString *u = (UnicodeString *) (strings + i);
         PyList_SET_ITEM(list, i, PyUnicode_FromUnicodeString(u));
@@ -817,6 +833,50 @@ static PyObject *t_dateformatsymbols_getLocale(t_dateformatsymbols *self,
     return PyErr_SetArgsError((PyObject *) self, "getLocale", args);
 }
 
+static PyObject *t_dateformatsymbols_getEraNames(t_dateformatsymbols *self)
+{
+    int count;
+    const UnicodeString *names = self->object->getEraNames(count);
+
+    return fromUnicodeStringArray(names, count, 0);
+}
+
+static PyObject *t_dateformatsymbols_getZoneStrings(t_dateformatsymbols *self)
+{
+    int rowCount, columnCount;
+    const UnicodeString **zoneStrings = self->object->getZoneStrings(rowCount, columnCount);
+    PyObject *rows = PyList_New(rowCount);
+
+    if (rows == NULL)
+        return NULL;
+
+    for (int i = 0; i < rowCount; ++i) {
+        PyList_SET_ITEM(rows, i, fromUnicodeStringArray(zoneStrings[i], columnCount, 0));
+    }
+
+    return rows;
+}
+
+#if U_ICU_VERSION_HEX >= VERSION_HEX(54, 0, 0)
+static PyObject *t_dateformatsymbols_getZodiacNames(t_dateformatsymbols *self, PyObject *args)
+{
+    DateFormatSymbols::DtContextType context;
+    DateFormatSymbols::DtWidthType width;
+
+    switch (PyTuple_Size(args)) {
+      case 2:
+        if (!parseArgs(args, "ii", &context, &width))
+        {
+            int count;
+            const UnicodeString *names = self->object->getZodiacNames(count, context, width);
+            return fromUnicodeStringArray(names, count, 0);
+        }
+        break;
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "getZodiacNames", args);
+}
+#endif // ICU >= 54
 
 /* DateFormat */
 
