@@ -36,6 +36,10 @@
     DECLARE_CONSTANTS_TYPE(UTimeUnitFormatStyle)
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+    DECLARE_CONSTANTS_TYPE(UMeasureFormatWidth)
+#endif
+
 #if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
     DECLARE_CONSTANTS_TYPE(UListFormatterField)
 #endif
@@ -77,8 +81,8 @@ static PyMethodDef t_fieldposition_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(FieldPosition, t_fieldposition, UObject, FieldPosition,
-             t_fieldposition_init, NULL)
+DECLARE_DEALLOC_TYPE(FieldPosition, t_fieldposition, UObject,
+                     FieldPosition, t_fieldposition_init)
 
 /* ParsePosition */
 
@@ -103,8 +107,8 @@ static PyMethodDef t_parseposition_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(ParsePosition, t_parseposition, UObject, ParsePosition,
-             t_parseposition_init, NULL)
+DECLARE_DEALLOC_TYPE(ParsePosition, t_parseposition, UObject,
+                     ParsePosition, t_parseposition_init)
 
 /* Format */
 
@@ -121,7 +125,7 @@ static PyMethodDef t_format_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(Format, t_format, UObject, Format, abstract_init, NULL)
+DECLARE_DEALLOC_TYPE(Format, t_format, UObject, Format, abstract_init)
 
 /* MeasureFormat */
 
@@ -131,6 +135,11 @@ public:
     PyObject *locale;
 };
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+static int t_measureformat_init(t_measureformat *self,
+                                PyObject *args, PyObject *kwds);
+#endif
+
 static PyObject *t_measureformat_createCurrencyFormat(PyTypeObject *type,
                                                       PyObject *args);
 #if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
@@ -143,6 +152,10 @@ static PyObject *t_measureformat_formatMeasures(t_measureformat *self,
 static PyObject *t_measureformat_formatMeasurePerUnit(t_measureformat *self,
                                                       PyObject *args);
 #endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(58, 0, 0)
+static PyObject *t_measureformat_getUnitDisplayName(t_measureformat *self,
+                                                    PyObject *arg);
+#endif
 
 static PyMethodDef t_measureformat_methods[] = {
     DECLARE_METHOD(t_measureformat, createCurrencyFormat, METH_VARARGS | METH_CLASS),
@@ -152,6 +165,9 @@ static PyMethodDef t_measureformat_methods[] = {
 #endif
 #if U_ICU_VERSION_HEX >= VERSION_HEX(55, 0, 0)
     DECLARE_METHOD(t_measureformat, formatMeasurePerUnit, METH_VARARGS),
+#endif
+#if U_ICU_VERSION_HEX >= VERSION_HEX(58, 0, 0)
+    DECLARE_METHOD(t_measureformat, getUnitDisplayName, METH_O),
 #endif
     { NULL, NULL, 0, NULL }
 };
@@ -167,8 +183,13 @@ static void t_measureformat_dealloc(t_measureformat *self)
     Py_TYPE(self)->tp_free((PyObject *) self);
 }
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+DECLARE_TYPE(MeasureFormat, t_measureformat, Format, MeasureFormat,
+             t_measureformat_init, t_measureformat_dealloc)
+#else
 DECLARE_TYPE(MeasureFormat, t_measureformat, Format, MeasureFormat,
              abstract_init, t_measureformat_dealloc)
+#endif
 
 #if U_ICU_VERSION_HEX >= 0x04020000
 
@@ -192,8 +213,8 @@ static PyMethodDef t_timeunitformat_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(TimeUnitFormat, t_timeunitformat, MeasureFormat, TimeUnitFormat,
-             t_timeunitformat_init, NULL)
+DECLARE_DEALLOC_TYPE(TimeUnitFormat, t_timeunitformat, MeasureFormat,
+                     TimeUnitFormat, t_timeunitformat_init)
 
 #endif
 
@@ -258,8 +279,8 @@ static PyMethodDef t_messageformat_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(MessageFormat, t_messageformat, Format, MessageFormat,
-             t_messageformat_init, NULL)
+DECLARE_DEALLOC_TYPE(MessageFormat, t_messageformat, Format,
+                     MessageFormat, t_messageformat_init)
 
 #if U_ICU_VERSION_HEX >= 0x04000000
 
@@ -291,8 +312,8 @@ static PyMethodDef t_pluralrules_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(PluralRules, t_pluralrules, UObject, PluralRules,
-             t_pluralrules_init, NULL)
+DECLARE_DEALLOC_TYPE(PluralRules, t_pluralrules, UObject,
+                     PluralRules, t_pluralrules_init)
 
 /* PluralFormat */
 
@@ -363,8 +384,8 @@ static PyMethodDef t_selectformat_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(SelectFormat, t_selectformat, Format, SelectFormat,
-             t_selectformat_init, NULL)
+DECLARE_DEALLOC_TYPE(SelectFormat, t_selectformat, Format,
+                     SelectFormat, t_selectformat_init)
 
 #endif
 
@@ -392,8 +413,8 @@ static PyMethodDef t_listformatter_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(ListFormatter, t_listformatter, UObject, ListFormatter,
-             abstract_init, NULL)
+DECLARE_DEALLOC_TYPE(ListFormatter, t_listformatter, UObject,
+                     ListFormatter, abstract_init)
 
 #endif
 
@@ -486,8 +507,9 @@ static PyMethodDef t_constrainedfieldposition_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(ConstrainedFieldPosition, t_constrainedfieldposition, UMemory,
-             ConstrainedFieldPosition, t_constrainedfieldposition_init, NULL)
+DECLARE_DEALLOC_TYPE(
+    ConstrainedFieldPosition, t_constrainedfieldposition, UMemory,
+    ConstrainedFieldPosition, t_constrainedfieldposition_init)
 
 /* FormattedValue */
 
@@ -505,8 +527,8 @@ static PyMethodDef t_formattedvalue_methods[] = {
     { NULL, NULL, 0, NULL }
 };
 
-DECLARE_TYPE(FormattedValue, t_formattedvalue, UMemory,
-             FormattedValue, abstract_init, NULL)
+DECLARE_DEALLOC_TYPE(FormattedValue, t_formattedvalue, UMemory,
+                     FormattedValue, abstract_init)
 
 PyObject *wrap_FormattedValue(FormattedValue *value)
 {
@@ -828,6 +850,37 @@ DEFINE_RICHCMP(Format, t_format)
 
 /* MeasureFormat */
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+
+static int t_measureformat_init(t_measureformat *self,
+                                PyObject *args, PyObject *kwds)
+{
+    UMeasureFormatWidth width;
+    Locale *locale;
+
+    switch (PyTuple_Size(args)) {
+      case 2:
+        if (!parseArgs(args, "Pi", TYPE_CLASSID(Locale), &locale, &width))
+        {
+            INT_STATUS_CALL(self->object = new MeasureFormat(*locale, width, status));
+            self->flags = T_OWNED;
+            break;
+        }
+        PyErr_SetArgsError((PyObject *) self, "__init__", args);
+        return -1;
+      default:
+        PyErr_SetArgsError((PyObject *) self, "__init__", args);
+        return -1;
+    }
+
+    if (self->object)
+        return 0;
+
+    return -1;
+}
+
+#endif
+
 static PyObject *t_measureformat_createCurrencyFormat(PyTypeObject *type,
                                                       PyObject *args)
 {
@@ -995,6 +1048,23 @@ static PyObject *t_measureformat_formatMeasurePerUnit(t_measureformat *self,
 }
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(58, 0, 0)
+static PyObject *t_measureformat_getUnitDisplayName(t_measureformat *self,
+                                                    PyObject *arg)
+{
+    MeasureUnit *unit;
+    UnicodeString u;
+
+    if (!parseArg(arg, "P", TYPE_CLASSID(MeasureUnit), &unit))
+    {
+        STATUS_CALL(u = self->object->getUnitDisplayName(*unit, status));
+        return PyUnicode_FromUnicodeString(&u);
+    }
+
+    return PyErr_SetArgsError((PyObject *) self, "getUnitDisplayName", arg);
+}
+#endif // ICU >= 58
+
 
 #if U_ICU_VERSION_HEX >= 0x04020000
 
@@ -2363,6 +2433,14 @@ void _init_format(PyObject *m)
     INSTALL_ENUM(UTimeUnitFormatStyle, "ABBREVIATED", UTMUTFMT_ABBREVIATED_STYLE);
 #endif
 
+#if U_ICU_VERSION_HEX >= VERSION_HEX(53, 0, 0)
+    INSTALL_CONSTANTS_TYPE(UMeasureFormatWidth, m)
+    INSTALL_ENUM(UMeasureFormatWidth, "WIDE", UMEASFMT_WIDTH_WIDE);
+    INSTALL_ENUM(UMeasureFormatWidth, "SHORT", UMEASFMT_WIDTH_SHORT);
+    INSTALL_ENUM(UMeasureFormatWidth, "NARROW", UMEASFMT_WIDTH_NARROW);
+    INSTALL_ENUM(UMeasureFormatWidth, "NUMERIC", UMEASFMT_WIDTH_NUMERIC);
+#endif
+
 #if U_ICU_VERSION_HEX >= VERSION_HEX(63, 0, 0)
     INSTALL_CONSTANTS_TYPE(UListFormatterField, m);
     INSTALL_ENUM(UListFormatterField, "LITERAL_FIELD", ULISTFMT_LITERAL_FIELD);
